@@ -578,7 +578,7 @@ class MongodbClient(AbstractClient):
 
 
     def InquirePriceCreateDBInstances(self, request):
-        """本接口用于创建数据库实例询价。本接口参数中必须传入region参数，否则无法通过校验。本接口仅允许针对购买限制范围内的实例配置进行询价。
+        """本接口（InquirePriceCreateDBInstances）用于创建数据库实例询价。本接口参数中必须传入region参数，否则无法通过校验。本接口仅允许针对购买限制范围内的实例配置进行询价。
 
         :param request: Request instance for InquirePriceCreateDBInstances.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.InquirePriceCreateDBInstancesRequest`
