@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBindInstance", params)
+            headers = request.headers
+            body = self.call("CreateBindInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBindInstanceResponse()
@@ -64,7 +65,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCosSecKeyInstance", params)
+            headers = request.headers
+            body = self.call("CreateCosSecKeyInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCosSecKeyInstanceResponse()
@@ -92,7 +94,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateResourceInstances", params)
+            headers = request.headers
+            body = self.call("CreateResourceInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateResourceInstancesResponse()
@@ -120,7 +123,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateScanInstances", params)
+            headers = request.headers
+            body = self.call("CreateScanInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateScanInstancesResponse()
@@ -148,7 +152,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateShieldInstance", params)
+            headers = request.headers
+            body = self.call("CreateShieldInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateShieldInstanceResponse()
@@ -176,7 +181,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateShieldPlanInstance", params)
+            headers = request.headers
+            body = self.call("CreateShieldPlanInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateShieldPlanInstanceResponse()
@@ -204,7 +210,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteScanInstances", params)
+            headers = request.headers
+            body = self.call("DeleteScanInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteScanInstancesResponse()
@@ -232,7 +239,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteShieldInstances", params)
+            headers = request.headers
+            body = self.call("DeleteShieldInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteShieldInstancesResponse()
@@ -250,6 +258,35 @@ class MsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeApkDetectionResult(self, request):
+        """该接口采用同步模式请求腾讯APK云检测服务，即时返回检测数据，需要用户用轮询的方式调用本接口来进行样本送检并获取检测结果(每隔60s发送一次请求，传相同的参数，重试30次)，一般情况下0.5h内会出检测结果，最长时间是3h。当Result为ok并且ResultList数组非空有值时，代表检测完毕，若长时间获取不到检测结果，请联系客服。
+
+        :param request: Request instance for DescribeApkDetectionResult.
+        :type request: :class:`tencentcloud.ms.v20180408.models.DescribeApkDetectionResultRequest`
+        :rtype: :class:`tencentcloud.ms.v20180408.models.DescribeApkDetectionResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeApkDetectionResult", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeApkDetectionResultResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeResourceInstances(self, request):
         """获取某个用户的所有资源信息
 
@@ -260,7 +297,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceInstances", params)
+            headers = request.headers
+            body = self.call("DescribeResourceInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceInstancesResponse()
@@ -289,7 +327,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeScanInstances", params)
+            headers = request.headers
+            body = self.call("DescribeScanInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeScanInstancesResponse()
@@ -317,7 +356,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeScanResults", params)
+            headers = request.headers
+            body = self.call("DescribeScanResults", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeScanResultsResponse()
@@ -346,7 +386,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeShieldInstances", params)
+            headers = request.headers
+            body = self.call("DescribeShieldInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeShieldInstancesResponse()
@@ -374,7 +415,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeShieldPlanInstance", params)
+            headers = request.headers
+            body = self.call("DescribeShieldPlanInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeShieldPlanInstanceResponse()
@@ -402,7 +444,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeShieldResult", params)
+            headers = request.headers
+            body = self.call("DescribeShieldResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeShieldResultResponse()
@@ -420,6 +463,35 @@ class MsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeUrlDetectionResult(self, request):
+        """移动安全-网址检测服务
+
+        :param request: Request instance for DescribeUrlDetectionResult.
+        :type request: :class:`tencentcloud.ms.v20180408.models.DescribeUrlDetectionResultRequest`
+        :rtype: :class:`tencentcloud.ms.v20180408.models.DescribeUrlDetectionResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeUrlDetectionResult", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUrlDetectionResultResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserBaseInfoInstance(self, request):
         """获取用户基础信息
 
@@ -430,7 +502,8 @@ class MsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUserBaseInfoInstance", params)
+            headers = request.headers
+            body = self.call("DescribeUserBaseInfoInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserBaseInfoInstanceResponse()
