@@ -55,37 +55,6 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def BlockByNumberHandler(self, request):
-        """版本升级
-
-        Bcos根据块高查询区块信息
-
-        :param request: Request instance for BlockByNumberHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.BlockByNumberHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.BlockByNumberHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("BlockByNumberHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.BlockByNumberHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateChaincodeAndInstallForUser(self, request):
         """创建并安装合约
 
@@ -144,37 +113,6 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DeployDynamicContractHandler(self, request):
-        """版本升级
-
-        动态部署合约
-
-        :param request: Request instance for DeployDynamicContractHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.DeployDynamicContractHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.DeployDynamicContractHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DeployDynamicContractHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeployDynamicContractHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DownloadUserCert(self, request):
         """下载用户证书
 
@@ -349,37 +287,6 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def GetBlockListHandler(self, request):
-        """版本升级
-
-        Bcos分页查询当前群组下的区块列表
-
-        :param request: Request instance for GetBlockListHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetBlockListHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetBlockListHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetBlockListHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetBlockListHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def GetBlockTransactionListForUser(self, request):
         """获取区块内的交易列表
 
@@ -670,68 +577,6 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def GetTransByHashHandler(self, request):
-        """版本升级
-
-        Bcos根据交易哈希查看交易详细信息
-
-        :param request: Request instance for GetTransByHashHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetTransByHashHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetTransByHashHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetTransByHashHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetTransByHashHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def GetTransListHandler(self, request):
-        """版本升级
-
-        Bcos分页查询当前群组的交易信息列表
-
-        :param request: Request instance for GetTransListHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.GetTransListHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.GetTransListHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetTransListHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetTransListHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def GetTransactionDetailForUser(self, request):
         """获取交易详情
 
@@ -877,6 +722,35 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InvokeChainMakerDemoContract(self, request):
+        """调用长安链体验网络合约执行交易
+
+        :param request: Request instance for InvokeChainMakerDemoContract.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.InvokeChainMakerDemoContractRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.InvokeChainMakerDemoContractResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InvokeChainMakerDemoContract", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InvokeChainMakerDemoContractResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def Query(self, request):
         """查询交易
 
@@ -964,6 +838,93 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def QueryChainMakerDemoBlockTransaction(self, request):
+        """查询长安链体验网络指定高度区块的交易
+
+        :param request: Request instance for QueryChainMakerDemoBlockTransaction.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoBlockTransactionRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoBlockTransactionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryChainMakerDemoBlockTransaction", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryChainMakerDemoBlockTransactionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryChainMakerDemoContract(self, request):
+        """调用长安链体验网络合约查询
+
+        :param request: Request instance for QueryChainMakerDemoContract.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoContractRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoContractResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryChainMakerDemoContract", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryChainMakerDemoContractResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryChainMakerDemoTransaction(self, request):
+        """通过交易ID查询长安链体验网络交易
+
+        :param request: Request instance for QueryChainMakerDemoTransaction.
+        :type request: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoTransactionRequest`
+        :rtype: :class:`tencentcloud.tbaas.v20180416.models.QueryChainMakerDemoTransactionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryChainMakerDemoTransaction", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryChainMakerDemoTransactionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def QueryChainMakerTransaction(self, request):
         """通过交易ID查询长安链交易
 
@@ -993,37 +954,6 @@ class TbaasClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def SendTransactionHandler(self, request):
-        """版本升级
-
-        Bcos发送交易
-
-        :param request: Request instance for SendTransactionHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.SendTransactionHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.SendTransactionHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("SendTransactionHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.SendTransactionHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def SrvInvoke(self, request):
         """trustsql服务统一接口
 
@@ -1046,37 +976,6 @@ class TbaasClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def TransByDynamicContractHandler(self, request):
-        """版本升级
-
-        根据动态部署的合约发送交易
-
-        :param request: Request instance for TransByDynamicContractHandler.
-        :type request: :class:`tencentcloud.tbaas.v20180416.models.TransByDynamicContractHandlerRequest`
-        :rtype: :class:`tencentcloud.tbaas.v20180416.models.TransByDynamicContractHandlerResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("TransByDynamicContractHandler", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.TransByDynamicContractHandlerResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
